import React, { useState, useEffect } from 'react';
import { motion, AnimatePresence, PanInfo, useAnimation, useScroll, useTransform } from 'framer-motion';
import { MapPin, ArrowRight, ChevronLeft, ChevronRight, Users, Clock, Award, Package, Globe } from 'lucide-react';
import { products } from '../data/products';
import { Product } from '../types';
import { useTranslation } from 'react-i18next';
import { useTheme } from './context/ThemeContext';
import { Link } from 'react-router-dom';
import { useInView } from 'react-intersection-observer';

function CounterAnimation({ end, duration = 2, label, icon: Icon, isDarkMode }: {
  end: number; 
  duration?: number; 
  label: string;
  icon: React.ElementType;
  isDarkMode: boolean;
}) {
  const [count, setCount] = useState(0);
  const [isHovered, setIsHovered] = useState(false);
  const [ref, inView] = useInView({
    triggerOnce: true,
    threshold: 0.1
  });

  useEffect(() => {
    if (!inView) return;

    let startTime: number | null = null;
    let animationFrame: number;

    const animate = (timestamp: number) => {
      if (!startTime) startTime = timestamp;
      const progress = (timestamp - startTime) / (duration * 1000);

      if (progress < 1) {
        setCount(Math.floor(end * progress));
        animationFrame = requestAnimationFrame(animate);
      } else {
        setCount(end);
      }
    };

    animationFrame = requestAnimationFrame(animate);
    return () => cancelAnimationFrame(animationFrame);
  }, [end, duration, inView]);

  return (
    <motion.div
      ref={ref}
      initial={{ opacity: 0, y: 20 }}
      animate={inView ? { opacity: 1, y: 0 } : { opacity: 0, y: 20 }}
      transition={{ duration: 0.6, ease: "easeOut" }}
      onMouseEnter={() => setIsHovered(true)}
      onMouseLeave={() => setIsHovered(false)}
      className={`relative overflow-hidden transform transition-all duration-300 ${
        isHovered ? 'scale-105' : ''
      }`}
    >
      <div className={`
        flex flex-col items-center p-8 rounded-2xl h-full min-h-[240px] w-full
        ${isDarkMode
          ? 'bg-gradient-to-br from-green-950/30 to-green-900/20 border border-green-800/20'
          : 'bg-gradient-to-br from-blue-50 to-blue-100/50 border border-blue-200/50'
        }
        backdrop-blur-sm
        transition-all duration-300
        ${isHovered
          ? isDarkMode
            ? 'shadow-lg shadow-green-500/10'
            : 'shadow-lg shadow-blue-500/20'
          : ''
        }
      `}>
        <div className={`
          relative mb-6 p-4 rounded-full
          ${isDarkMode
            ? 'bg-gradient-to-br from-green-500/10 to-green-400/10'
            : 'bg-gradient-to-br from-blue-200 to-blue-300/50'
          }
          transition-all duration-300
          ${isHovered ? 'scale-110' : ''}
        `}>
          <Icon className={`
            w-8 h-8
            ${isDarkMode
              ? 'text-green-400'
              : 'text-blue-600'
            }
            transition-all duration-300
            ${isHovered
              ? isDarkMode
                ? 'text-green-300'
                : 'text-blue-500'
              : ''
            }
          `} />
          <div className={`
            absolute inset-0 rounded-full
            ${isDarkMode
              ? 'bg-green-400/10'
              : 'bg-blue-400/20'
            }
            animate-ping
          `} />
        </div>

        <div className={`
          text-5xl font-bold mb-3
          ${isDarkMode
            ? 'bg-gradient-to-r from-green-400 to-emerald-400 bg-clip-text text-transparent'
            : 'bg-gradient-to-r from-blue-600 to-blue-500 bg-clip-text text-transparent'
          }
          transition-all duration-300
          ${isHovered ? 'tracking-wider' : ''}
        `}>
          {count}+
        </div>

        <div className="text-center">
          <span className={`
            text-sm font-medium uppercase tracking-wider
            ${isDarkMode
              ? 'text-gray-400'
              : 'text-gray-600'
            }
            transition-all duration-300
            ${isHovered
              ? isDarkMode
                ? 'text-green-300'
                : 'text-blue-600'
              : ''
            }
          `}>
            {label}
          </span>
        </div>
      </div>
    </motion.div>
  );
}

function App() {
  const { t } = useTranslation();
  const { isDarkMode } = useTheme();
  const [featuredProducts, setFeaturedProducts] = useState<Product[]>([]);
  const [currentIndex, setCurrentIndex] = useState(0);
  const [hoveredIndex, setHoveredIndex] = useState<number | null>(null);
  const [isMobile, setIsMobile] = useState(window.innerWidth < 768);

  const [heroRef, heroInView] = useInView({ threshold: 0.1, triggerOnce: true });
  const [categoriesRef, categoriesInView] = useInView({ threshold: 0.1, triggerOnce: true });
  const [statsRef, statsInView] = useInView({ threshold: 0.1, triggerOnce: true });
  const [productsRef, productsInView] = useInView({ threshold: 0.1, triggerOnce: true });
  const [aboutRef, aboutInView] = useInView({ threshold: 0.1, triggerOnce: true });

  const categories = [
    {
      name: t('categories.Rezistanslar.name'),
      image: '/photos/itemphotos/rezistans/fisek/f9.jpg',
      href: '/rezistanslar',
      icon: Package,
      alt: 'Rezistanslar - Industrial Heating Elements',
    },
    {
      name: t('categories.Sıcak Yolluk Sistemleri.subcategories.Sıcak Yolluk Ünite'),
      image: '/photos/itemphotos/1.JPEG',
      href: '/product/sicakyolluksistemleri',
      icon: Package,
      alt: 'Sıcak Yolluk Ünite - Hot Runner Systems',
    },
    {
      name: t('categories.Dirençler.name'),
      image: '/photos/itemphotos/2.JPEG',
      href: '/direncler',
      icon: Package,
      alt: 'Dirençler - Industrial Resistors',
    },
    {
      name: t('categories.Pano Isıtıcısı.name'),
      image: '/photos/itemphotos/4.JPEG',
      href: '/product/panoisitici',
      icon: Package,
      alt: 'Pano Isıtıcısı - Control Panel Heaters',
    }
  ];

  useEffect(() => {
    const handleResize = () => {
      setIsMobile(window.innerWidth < 768);
    };

    window.addEventListener('resize', handleResize);
    return () => window.removeEventListener('resize', handleResize);
  }, []);

  useEffect(() => {
    const shuffled = [...products].sort(() => Math.random() - 0.5);
    setFeaturedProducts(shuffled.slice(0, 6));
  }, []);

  const itemsPerPage = isMobile ? 1 : 3;
  const totalItems = featuredProducts.length;
  const maxIndex = totalItems - itemsPerPage;

  const paginate = (direction: number) => {
    const newIndex = currentIndex + direction;
    if (newIndex >= 0 && newIndex <= maxIndex) {
      setCurrentIndex(newIndex);
    }
  };

  const handleDragEnd = (event: MouseEvent | TouchEvent | PointerEvent, info: PanInfo) => {
    const swipeThreshold = 50;
    if (Math.abs(info.offset.x) > swipeThreshold) {
      if (info.offset.x > 0 && currentIndex > 0) {
        paginate(-1);
      } else if (info.offset.x < 0 && currentIndex < maxIndex) {
        paginate(1);
      }
    }
  };

  const fadeInUp = {
    hidden: { opacity: 0, y: 20 },
    visible: {
      opacity: 1,
      y: 0,
      transition: { duration: 0.6, ease: "easeOut" }
    }
  };

  const staggerChildren = {
    hidden: { opacity: 0 },
    visible: {
      opacity: 1,
      transition: {
        staggerChildren: 0.2
      }
    }
  };

  const visibleProducts = featuredProducts.slice(
    currentIndex,
    currentIndex + itemsPerPage
  );

  const ProductCard = ({ product, index }: { product: Product, index: number }) => (
    <Link to={`/product/${product.id}`}>
      <motion.div
        layout
        initial={false}
        className={`relative group cursor-pointer rounded-2xl overflow-hidden h-full ${
          isDarkMode
            ? 'bg-black border border-green-900/50' 
            : 'bg-white shadow-lg'
        } transition-all duration-300`}
        style={{
          boxShadow: isDarkMode
            ? '0 10px 30px -15px rgba(0, 0, 0, 0.3)'
            : '0 10px 30px -15px rgba(0, 0, 0, 0.1)'
        }}
        onMouseEnter={() => setHoveredIndex(index)}
        onMouseLeave={() => setHoveredIndex(null)}
      >
        <div className="relative aspect-[4/3] overflow-hidden">
          <motion.img
            src={product.image}
            alt={t(product.name)}
            className="w-full h-full object-cover"
            whileHover={{
              scale: 1.05,
              transition: { duration: 0.6 }
            }}
          />
        </div>
        <motion.div className="p-6 flex flex-col h-full" initial={false}>
          <motion.h3
            className={`text-xl font-bold mb-2 ${
              isDarkMode ? 'text-green-400' : 'text-blue-600'
            }`}
            whileHover={{ x: 4 }}
            transition={{ duration: 0.2 }}
          >
            {t(product.name)}
          </motion.h3>
          <motion.p
            className={`text-base flex-grow ${
              isDarkMode ? 'text-gray-400' : 'text-gray-600'
            }`}
            whileHover={{ x: 4 }}
            transition={{ duration: 0.2 }}
          >
            {t(product.name2)}
          </motion.p>
          <div className="mt-4 flex items-center justify-between">
            <span className={`text-sm font-medium ${isDarkMode ? 'text-green-400' : 'text-blue-600'}`}>
              {t(product.category)}
            </span>
            <motion.span
              whileHover={{ x: 5 }}
              className={`${isDarkMode ? 'text-green-400 hover:text-green-300' : 'text-blue-600 hover:text-blue-700'}`}
            >
              {t('products.learnMore')} →
            </motion.span>
          </div>
        </motion.div>
      </motion.div>
    </Link>
  );

  return (
    <div className={`min-h-screen ${isDarkMode ? 'bg-black' : 'bg-gray-50'}`}>
      {/* Hero Section */}
      <motion.div
        ref={heroRef}
        initial="hidden"
        animate={heroInView ? "visible" : "hidden"}
        variants={staggerChildren}
        className="container mx-auto px-4 py-16 max-w-7xl"
      >
        <div className="grid lg:grid-cols-2 gap-16 items-center">
          {/* Left Side */}
          <div className="space-y-10">
            <motion.div
              variants={fadeInUp}
              className="space-y-4"
            >
              <div className={`inline-block ${isDarkMode ? 'bg-green-600/20' : 'bg-blue-600/20'} rounded-full px-4 py-1 text-sm font-medium ${isDarkMode ? 'text-green-400' : 'text-blue-600'}`}>
                {t('homepagei18.11')}
              </div>
              <h1 className={`text-4xl sm:text-5xl md:text-6xl font-bold tracking-tight ${isDarkMode ? 'text-white' : 'text-gray-900'} transition-colors duration-300`}>
                Dinamik<span className={isDarkMode ? 'text-green-500' : 'text-blue-600'}>Rezistans</span>
              </h1>
            </motion.div>
            <motion.p
              variants={fadeInUp}
              className={`text-xl leading-relaxed ${isDarkMode ? 'text-gray-300' : 'text-gray-600'} transition-colors duration-300 max-w-lg`}  
            >
              {t('homepagei18.7')}
            </motion.p>
            <motion.div
              variants={fadeInUp}
              className="flex items-center space-x-6"
            >
              <button className={`group relative overflow-hidden px-8 py-4 rounded-full font-medium text-white transition-all duration-300 ${  
                isDarkMode ? 'bg-green-600 hover:bg-green-500' : 'bg-blue-600 hover:bg-blue-500'
              }`}>
                <a href="/products" className="relative z-10 flex items-center">
                  {t('homepagei18.8')}
                  <ArrowRight className="ml-2 transform group-hover:translate-x-1 transition-transform duration-300" />
                </a>
                <div className="absolute inset-0 transform scale-x-0 group-hover:scale-x-100 transition-transform duration-300 origin-left bg-gradient-to-r from-transparent via-white/10 to-transparent"></div>
              </button>
              <a href="/about" className={`font-medium transition-colors duration-300 ${
                isDarkMode ? 'text-gray-400 hover:text-white' : 'text-gray-600 hover:text-gray-900'
              }`}>
                {t('homepagei18.9')}
              </a>
            </motion.div>
          </div>

          {/* Categories Grid */}
          <motion.div
            ref={categoriesRef}
            initial="hidden"
            animate={categoriesInView ? "visible" : "hidden"}
            variants={staggerChildren}
            className="grid grid-cols-2 gap-6"
          >
            {categories.map((category, index) => (
              <motion.a
                key={category.name}
                variants={fadeInUp}
                custom={index}
                href={category.href}
                className={`group relative overflow-hidden rounded-2xl transition-all duration-500 hover:scale-105 ${
                  isDarkMode 
                    ? 'bg-gray-900/50 hover:bg-gray-800/50 ring-1 ring-green-500/10' 
                    : 'bg-white hover:shadow-xl'
                } shadow-lg`}
              >
                <div className="aspect-square relative">
                  <img
                    src={category.image}
                    alt={category.alt}
                    className="object-cover w-full h-full transition-transform duration-500 group-hover:scale-110"
                  />
                  <div className={`absolute inset-0 bg-gradient-to-t ${
                    isDarkMode 
                      ? 'from-gray-900/80 via-gray-900/30 to-transparent' 
                      : 'from-gray-900/90 via-gray-900/40 to-transparent'
                  } opacity-60 group-hover:opacity-70 transition-opacity duration-300`}></div>
                  <div className="absolute bottom-0 left-0 right-0 p-6 transform transition-transform duration-300">
                    {/* Category Name & Icon */}
                    <div className="hidden sm:flex items-center space-x-3 mb-3">
                      <div className={`p-2 rounded-full backdrop-blur-sm ${
                        isDarkMode 
                          ? 'bg-green-400/10 text-green-300' 
                          : 'bg-white/30 text-white'
                      } group-hover:scale-110 transition-all duration-300`}>
                        <category.icon size={20} />
                      </div>
                      <h3 className="text-xl font-semibold text-white drop-shadow-sm">
                        {category.name}
                      </h3>
                    </div>
                    {/* Arrow & Text */}
                    <div className="flex items-center justify-start text-sm font-medium text-white pr-4 sm:pr-0">
                      <span className="drop-shadow-sm">
                        {t('homepagei18.10')}
                      </span>
                      <ArrowRight 
                        size={16} 
                        className="ml-1 transform group-hover:translate-x-1 transition-transform duration-300" 
                      />
                    </div>
                  </div>
                </div>
              </motion.a>
            ))}
          </motion.div>
        </div>
      </motion.div>

      {/* Stats Section */}
      <motion.div
        ref={statsRef}
        initial="hidden"
        animate={statsInView ? "visible" : "hidden"}
        variants={staggerChildren}
        className={`w-full py-16 ${
          isDarkMode
            ? 'bg-green-950/20 border-y border-green-900/30'
            : 'bg-blue-50/50 shadow-inner'
        }`}
      >
        <div className="container mx-auto px-6 max-w-7xl">
          <div className="grid grid-cols-2 md:grid-cols-4 gap-6">
            <CounterAnimation
              end={35}
              label={t('About.4')}
              icon={Clock}
              duration={2.5}
              isDarkMode={isDarkMode}
            />
            <CounterAnimation
              end={1000}
              label={t('About.1')}
              icon={Users}
              duration={2}
              isDarkMode={isDarkMode}
            />
            <CounterAnimation
              end={50}
              label={t('About.29')}
              icon={Package}
              duration={2.2}
              isDarkMode={isDarkMode}
            />
            <CounterAnimation
              end={35}
              label={t('About.30')}
              icon={Globe}
              duration={1.8}
              isDarkMode={isDarkMode}
            />
          </div>
        </div>
      </motion.div>

      {/* Products Section */}
      <motion.div
        ref={productsRef}
        initial="hidden"
        animate={productsInView ? "visible" : "hidden"}
        variants={staggerChildren}
        className="container mx-auto px-6 py-24 max-w-7xl"
      >
        <div className="flex flex-col md:flex-row justify-between items-start md:items-center gap-4 mb-8">
          <div>
            <h2 className={`text-3xl font-bold ${isDarkMode ? 'text-green-400' : 'text-blue-600'}`}>
              {t('homepagei18.3')}
            </h2>
            <p className={`mt-2 text-lg ${isDarkMode ? 'text-gray-400' : 'text-gray-600'}`}>
              {t('homepagei18.4')}
            </p>
          </div>
          <Link to="/products">
            <motion.button
              whileHover={{ scale: 1.02 }}
              whileTap={{ scale: 0.98 }}
              className={`group flex items-center gap-2 px-6 py-3 rounded-xl font-medium transition-all duration-300 ${
                isDarkMode
                  ? 'bg-green-800/30 text-green-400 hover:bg-green-800/50'
                  : 'bg-blue-100 text-blue-600 hover:bg-blue-200'
              }`}
            >
              {t('recommendations.viewAll')}
              <ArrowRight className="w-5 h-5 transition-transform duration-300 group-hover:translate-x-1" />
            </motion.button>
          </Link>
        </div>

        <motion.div
          drag={isMobile ? "x" : false}
          dragConstraints={{ left: 0, right: 0 }}
          dragElastic={0.2}
          onDragEnd={handleDragEnd}
          className={`grid ${isMobile ? 'grid-cols-1' : 'grid-cols-3'} gap-6 md:gap-8`}
        >
          <AnimatePresence mode="wait">
            {visibleProducts.map((product: Product, index: number) => (
              <motion.div
                key={`${product.id}-${index}`}
                initial={{ opacity: 0, x: 50 }}
                animate={{ opacity: 1, x: 0 }}
                exit={{ opacity: 0, x: -50 }}
                transition={{ duration: 0.3 }}
              >
                <ProductCard product={product} index={index} />
              </motion.div>
            ))}
          </AnimatePresence>
        </motion.div>

        {totalItems > itemsPerPage && (
          <div className="flex justify-center items-center mt-12 gap-6">
            <motion.button
              whileHover={{ scale: 1.1 }}
              whileTap={{ scale: 0.9 }}
              onClick={() => paginate(-1)}
              disabled={currentIndex === 0}
              className={`p-3 rounded-full transition-all duration-300 ${
                isDarkMode
                  ? 'bg-green-800/30 text-green-400 hover:bg-green-800/50 disabled:opacity-50'
                  : 'bg-blue-100 text-blue-600 hover:bg-blue-200 disabled:opacity-50'
              }`}
            >
              <ChevronLeft className="w-6 h-6" />
            </motion.button>

            <div className="flex gap-3">
              {[...Array(maxIndex + 1)].map((_, i) => (
                <motion.button
                  key={i}
                  whileHover={{ scale: 1.2 }}
                  whileTap={{ scale: 0.9 }}
                  onClick={() => setCurrentIndex(i)}
                  className={`w-2 h-2 rounded-full transition-all duration-300 ${
                    currentIndex === i
                      ? isDarkMode
                        ? 'bg-green-400 scale-110'
                        : 'bg-blue-600 scale-110'
                      : isDarkMode
                        ? 'bg-green-800/30 hover:bg-green-800/50'
                        : 'bg-blue-200 hover:bg-blue-300'
                  }`}
                />
              ))}
            </div>

            <motion.button
              whileHover={{ scale: 1.1 }}
              whileTap={{ scale: 0.9 }}
              onClick={() => paginate(1)}
              disabled={currentIndex >= maxIndex}
              className={`p-3 rounded-full transition-all duration-300 ${
                isDarkMode
                  ? 'bg-green-800/30 text-green-400 hover:bg-green-800/50 disabled:opacity-50'
                  : 'bg-blue-100 text-blue-600 hover:bg-blue-200 disabled:opacity-50'
              }`}
            >
              <ChevronRight className="w-6 h-6" />
            </motion.button>
          </div>
        )}
      </motion.div>

      {/* About Section */}
      <motion.div
        ref={aboutRef}
        initial="hidden"
        animate={aboutInView ? "visible" : "hidden"}
        variants={staggerChildren}
        className={`py-20 ${isDarkMode ? 'bg-black border-t border-green-900/30' : 'bg-white shadow-inner'}`}
      >
        <div className="container mx-auto px-6 max-w-7xl">
          <div className="grid grid-cols-1 lg:grid-cols-2 gap-12 items-center">
            <motion.div variants={fadeInUp}>
              <h2 className={`text-4xl font-bold mb-6 ${isDarkMode ? 'text-green-400' : 'text-blue-600'}`}>
                {t('nav.about')}
              </h2>
              <p className={`text-xl mb-8 ${isDarkMode ? 'text-gray-400' : 'text-gray-600'}`}>
                {t('homepagei18.1')}
              </p>
              <div className={`flex items-center space-x-4 ${isDarkMode ? 'text-gray-400' : 'text-gray-600'}`}>
                <MapPin className="w-6 h-6" />
                <span>Şerifali, Edep Sk. No:38, 34776 Ümraniye/İstanbul</span>
              </div>
            </motion.div>
            <motion.div
              variants={fadeInUp}
              className={`h-[400px] rounded-xl overflow-hidden ${isDarkMode ? 'border border-green-900/30' : 'shadow-lg'}`}
            >
              <iframe

               
 src="https://www.google.com/maps/embed?pb=!1m18!1m12!1m3!1d3011.1879254795313!2d29.151739!3d40.999259800000004!2m3!1f0!2f0!3f0!3m2!1i1024!2i768!4f13.1!3m3!1m2!1s0x14cacf5577f613a7%3A0x98754343c98970ad!2sDinamik%20Rezistans!5e0!3m2!1sru!2str!4v1744404842989!5m2!1sru!2str" 


                width="100%"
                height="100%"
                style={{ border: 0 }}
                allowFullScreen
                loading="lazy"
              ></iframe>
            </motion.div>
          </div>
        </div>
      </motion.div>
    </div>
  );
}

export default App;
